@@ -1,3 +1,14 @@
+#
+# $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/windows.tcl,v $
+# $Date: 1998/04/14 12:22:07 $
+# $Revision: 1.18.1.16 $
+#
+# ----------------------------------------------------------------------
+#   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
+# ----------------------------------------------------------------------
+# Copyright 1998 The University of Newcastle upon Tyne (see COPYRIGHT)
+# ======================================================================
+#
 package provide windows 1.18
 #
 proc install {argv} {
@@ -5,7 +16,7 @@ proc install {argv} {
       libs share SCflag GCC SLDflag CFlags TIDir NoGUI Xtn go
 #
     package require support
-    package require unixfile
+    package require winfile
 #
     switch -glob -- [info tclversion] 7.* {
         tk_dialog .wdz {Windows Installation} {Sorry, you  must have tcl/tk version\
@@ -14,9 +25,9 @@ proc install {argv} {
     }
 #
     set argv [doGlobals $argv]
-    set Lib {C:\Program Files\Zircon}
+    set Lib [file join C: {Program Files} Zircon]
     set Bin $Lib
-    trace variable Lib w {set Bin $Lib}
+    trace variable Lib w traceLib
     set Xtn .tcl
 #
     set w [mainWindow]
@@ -39,9 +50,13 @@ proc install {argv} {
     putButtons $w
 }
 #
+proc traceLib {args} { global Bin Lib ; set Bin $Lib }
+#
 proc prog7 {args} { }
 #
 proc sed {args} { }
+#
+proc whereLib {} { return {[pwd]} }
 
 
 
