@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/zircon.tcl,v $
-# $Date: 1998/03/25 10:42:54 $
-# $Revision: 1.18.1.11 $
+# $Date: 1998/04/29 11:44:40 $
+# $Revision: 1.18.1.13 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -38,9 +38,6 @@ proc zUnknown {args} {
     }
 }
 #
-rename unknown sys_unknown
-rename zUnknown unknown
-#
 Initialise
 #
 # save some space!!! it will reload if necessary.
@@ -76,13 +73,16 @@ if {[set l [llength [set nets [Net :: list]]]] == 1} {
 }
 safeUnset l net nets
 #
+rename unknown sys_unknown
+rename zUnknown unknown
+#
 if {!$zircon(C)} {
     foreach x $znetList {
 	switch nil [set hst [$x hostid]] {} default {
 	    set s [$x servers]
 	    set v [lsearch $s $hst]
 	    listdel s $v
-	    while {![$x startIRC $hst]} {
+	    while {![$x startIRC $hst -noretry]} {
 		switch {} $s {
 		    [$x control] enableOpen
 		    break
