@@ -1,12 +1,12 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lang/RCS/deutsch.tcl,v $
+# $Source: /home/nlfm/Working/Zircon/Released/lang//RCS/deutsch.tcl,v $
 # $Date: 1997/02/14 09:43:05 $
 # $Revision: 1.18.1.3 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
 #   TRANSLATOR: Klaus Luft <Klaus.Luft@stud.uni-karlsruhe.de>
-#               Dirk F=F6rsterling <dirk@informatik.uni-frankfurt.de>
+#               Dirk Frsterling <dirk@informatik.uni-frankfurt.de>
 #
 #   Note from Dirk:
 #		Some translated words will sound horrible to native
@@ -20,9 +20,7 @@
 #
 # ----------------------------------------------------------------------
 # Copyright 1996 The University of Newcastle upon Tyne (see COPYRIGHT)
-# =3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
-=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=
-=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D=3D
+# 
 #
 array set ztrans {
     abort	Abbrechen
@@ -30,37 +28,37 @@ array set ztrans {
     action	Aktion
     actions	Aktionen
     anonymous	Anonym
-    append	Anh=E4ngen
+    append	Anhngen
     away	{Bin weg}
     back	{Wieder da}
     ban		Verbannen
     brb		BGZ
-    busy	Besch=E4ftigt
-    buttons	Kn=F6pfe
+    busy	Beschftigt
+    buttons	Knpfe
     call        Aufrufen
     cancel	Abbrechen
     channel	Kanal
-    channels	Kan=E4le
+    channels	Kanle
     chanop	KanalOp
     chat	Chat
-    clear	L=F6schen
+    clear	Lschen
     clone	Duplizieren
-    close	Schlie=DFen
+    close	Schlieen
     configure	Konfigurieren
     connect	Verbinden
-    crypt	Verschl=FCsseln
+    crypt	Verschlsseln
     ctcp	CTCP
     dcc		DCC
     debug	Debug
     default	Vorgabe
-    delete	L=F6schen
+    delete	Lschen
     dismiss	Ende
     draw	Zeichnen
     dump	Dump
     edit	Bearbeiten
     empty	Leeren
     error	Fehler
-    exec	Ausf=FChren
+    exec	Ausfhren
     favourites	Favoriten
     filename	Dateiname
     filter	Filter
@@ -75,10 +73,10 @@ array set ztrans {
     invite	Einladen
     irc		IRC
     ircname	IRC-Name
-    join	=D6ffnen
+    join	ffnen
     jump	Springen
     keep	Behalten
-    key		Schl=FCssel
+    key		Schlssel
     kick	Kicken
     kill	Kill
     leave	Verlassen
@@ -91,7 +89,7 @@ array set ztrans {
     messages	Nachrichten
     mode	Modus
     moderated	Moderiert
-    monitor	=DCberwachen
+    monitor	berwachen
     name	Name
     names	Namen
     new		Neu
@@ -101,7 +99,7 @@ array set ztrans {
     notify	Benachrichtigen
     offer	Anbieten
     ok		OK
-    open	=D6ffnen
+    open	ffnen
     operator	Operator
     other	Andere
     parameter	Parameter
@@ -119,7 +117,7 @@ array set ztrans {
     refresh	Auffrischen
     register	Registrieren
     reject	Ablehnen
-    rejoin	{Erneut anw=E4hlen}
+    rejoin	{Erneut anwhlen}
     save	Speichern
     script	Skript
     scroll	Scroll
@@ -130,7 +128,7 @@ array set ztrans {
     service	Dienst
     services	Dienste
     set		Einstellen
-    shutdown	Abschlu=DF
+    shutdown	Abschlu
     signoff	{Kanal verlassen}
     silence	Stummschalten
     sound	Klang
@@ -140,7 +138,7 @@ array set ztrans {
     type	Eingeben
     topic	Thema
     unban	{Bann aufheben}
-    unload	{Laden r=FCckg=E4ngig}
+    unload	{Laden rckgngig}
     user	Teilnehmer
     users	Teilnehmer
     view	Ansicht
