@@ -16,6 +16,7 @@ array set ztrans {
     actions	Actions
     anonymous	Anonymous
     append	Append
+    apply	Apply
     away	Away
     back	Back
     ban		Ban
@@ -52,6 +53,7 @@ array set ztrans {
     finger	Finger
     flags	Flags
     flush	Flush
+    friends	Friends
     get		Get
     help	Help
     history	History
@@ -108,6 +110,7 @@ array set ztrans {
     register	Register
     reject	Reject
     rejoin	Rejoin
+    revert	Revert
     save	Save
     script	Script
     scroll	Scroll
