@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Away.tcl,v $
-# $Date: 1998/02/09 16:56:23 $
-# $Revision: 1.18.1.19 $
+# $Date: 1998/04/29 11:44:17 $
+# $Revision: 1.18.1.20 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -13,9 +13,7 @@ package provide zircon 1.18
 #
 proc awayPanel {net} {
     if {[winfo exists [set w .@aw$net]]} { popup $w ; return }
-    toplevel $w -class Zircon
-    wm resizable $w 1 1
-    wm title $w {Away Messages}
+    set wid [Window $w -title {Away Messages}]
     upvar #0 $net ndata
     grid rowconfigure $w 1 -weight 1
     foreach x {0 1 2} {grid columnconfigure $w $x -weight 1}
@@ -39,7 +37,7 @@ proc awayPanel {net} {
     button $w.clear -text [trans clear] -command "$net clearAway $w" \
       -state disabled
     if {$ndata(busy) || $ndata(away)} { $w.clear configure -state normal }
-    button $w.cancel -text [trans dismiss] -command "destroy $w"
+    button $w.cancel -text [trans dismiss] -command "$wid delete"
     button $w.new -text [trans new] -command "$net getAway $w.aways.l"
     button $w.edit -text [trans edit] -command "$net editAway $w.aways.l" -state disabled
     button $w.del -text [trans delete] -command "$net delAway $w.aways.l" -state disabled
