@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Channel.tcl,v $
-# $Date: 1998/04/20 11:42:09 $
-# $Revision: 1.18.1.145 $
+# $Date: 1998/04/27 11:45:55 $
+# $Revision: 1.18.1.147 $
 #
 #
 package provide zircon 1.18
@@ -220,8 +220,8 @@ proc channel_setTopic {this string} {
 #
 proc channel_changeMode {this mode} {
     upvar #0 $this cdata
-    set val $cdata($mode)
-#    set cdata($mode) [expr {!$val}]
+    set val $cdata(lcl$mode)
+    set cdata(lcl$mode) [expr {!$val}]
     [$this net] MODE [$this name] [expr {$val ? {+} : {-}}]${mode}
 }
 #
@@ -430,7 +430,8 @@ proc channel_slowJoin {this} {
     $this clearNames
     [$this net] sysQ "JOIN [$this name] :[$this key]"
     upvar #0 $this cdata
-    foreach x {p m s i t n a} { set cdata($x) 0 }
+    array set cdata {p 0 lclp 0 m 0 lclm 0 s 0 lcls 0 i 0 \
+      lcli 0 t 0 lclt 0 n 0 lcln 0 a 0 lcla 0 }
 }
 #
 proc channel_sendJoin {this args} {
@@ -445,7 +446,8 @@ proc channel_putJoin {this key} {
     switch {} $key {} default { $this configure -key $key }
     [$this net] qSend JOIN [$this name] :[$this key]
     upvar #0 $this cdata
-    array set cdata {p 0 m 0 s 0 i 0 t 0 n 0 a 0}
+    array set cdata {p 0 lclp 0 m 0 lclm 0 s 0 lcls 0 i 0 \
+      lcli 0 t 0 lclt 0 n 0 lcln 0 a 0 lcla 0 }
 }
 #
 proc channel_rejoin {this} {
@@ -929,8 +931,6 @@ proc makeCtlMode {this net w chan rchan idx look} {
     $om add checkbutton -label [trans draw] -variable ${this}(draw) \
       -command "$this drawSet"
     if {[$this isa Chat]} { $om entryconfigure last -state disabled }
-#    $om add checkbutton -label [trans jump] -variable ${this}(jump) \
-#	-command "$this set jump"
     $om add checkbutton -label [trans quiet] -variable ${this}(quiet) \
 	-command "$this set quiet"
     $om add checkbutton -label [trans actions] -variable ${this}(actions) \
@@ -945,17 +945,18 @@ proc makeCtlMode {this net w chan rchan idx look} {
 	set efs29 [string match 2.9* [$net sVersion]]
 	if {!$efs29 || ![string match +* $rchan]} {
 	    $om add command -command "$this setBan" -label [trans ban]
-	    foreach vl "{p [trans private]} {m [trans moderated]} \
-	      {s [trans secret]} {i {Invite Only}} {t [trans topic]} \
-	      {n {No Msg}}" {
-		set v [lindex $vl 0]
+	    foreach {v tx} "p private m moderated \
+	      s secret i {Invite Only} t topic n {No Msg}" {
+	        uplevel #0 trace variable ${this}($v) w "{updVar $this}"
 		set cdata($v) 0
 		$om add checkbutton -command "$this changeMode $v" \
-		  -variable ${this}($v) -state disabled -label [lindex $vl 1]
+		  -variable ${this}(lcl$v) -state disabled -label [trans $tx]
 	    }
 	    if {$efs29 && [string match {&*} $rchan]} {
+	        uplevel #0 trace variable ${this}(a) w "{updVar $this}"
+		set cdata(a) 0
 		$om add checkbutton -command "$this changeMode a" \
-		  -variable ${this}(a) -state disabled -label [trans anonymous]
+		  -variable ${this}(lcla) -state disabled -label [trans anonymous]
 	    }
 	    $om add command -command "$this setLimit" -label [trans limit]
 	    $om add command -command "$this setKey" -label [trans key]
@@ -1155,10 +1156,26 @@ proc channel_keepMsg {this str} {
     }
 }
 #
+proc lclTrace {chan var} {
+    switch {} [uplevel #0 trace vinfo ${chan}($var)] {
+        uplevel #0 trace variable ${chan}($var) w "{updVar $chan}"
+        uplevel #0 trace variable ${chan}($var) u "{unsVar $chan}"
+    }
+}
+#
+proc updVar {chan n1 n2 op} {
+    upvar #0 $chan cdata
+    set cdata(lcl$n2) $cdata($n2)
+}
+#
+proc unsVar {chan n1 n2 op} { uplevel #0 unset ${this}(lcl$n2) }
+#
 proc channel_buildUsersMenu {this w} {
     upvar #0 $this cdata
     set myid [[$this net] myid]
+    lclTrace $this Op,$myid
     set cdata(Op,$myid) 0
+    lclTrace $this Spk,$myid
     set cdata(Spk,$myid) 0
     $w add command -label [expr {[$this buttons] ? {No Buttons} : {Buttons}}] \
       -command "$this toggleUsers"
@@ -1215,6 +1232,7 @@ proc mcnDelete {this nvar reg} {
 	    $this configure -mwin {}
 	}
 	if {[$this keep]} { $this configure -joinat [$this joinat] }
+	$this configure -leaving 0
     }
     safeUnset Bl($this) Bg($this) Fg($this) BF($this) Ft($this) MkOp${net}($this)
     safeDestroy .@pal${this}Entry .@pal${this}Topic .@pp${this}Entry .@pp${this}Topic
@@ -1287,7 +1305,8 @@ proc channel_doLeave {this msg} {
     set net [$this net]
     if {[$this isa Channel] && [$net active]} {
 	set w [$this window]
-	catch {$w.quit configure -state disabled -text Leaving}
+	catch {$w.quit configure -state disabled -text [trans leaving]}
+	$this configure -leaving 1
 	catch {$w.cmd.entry configure -state disabled}
 	$net PART [$this name] $msg
     } {
@@ -1401,7 +1420,7 @@ proc doMarking {this usr knd op state val} {
     uplevel #0 set ${this}($knd,$usr) $val
     if {[[$this net] me $usr]} { $this opItems $state }
     set w [$this window]
-    markButton [$this ufrm].userBtn.$usr $op
+    markButton [$this net] [$this ufrm].userBtn.$usr $op
     markEntry $w.users.menu [indexHack $w.users.menu [$usr name] 3] $op
     if {[$this m]} { $this showFlags mod Moderated }
 }
@@ -1410,7 +1429,7 @@ proc channel_Vmarker {this usr v1 v2} {
     uplevel #0 set ${this}(Spk,$usr) $v2
     if {![$this isOp $usr]} {
 	set w [$this window]
-	markButton [$this ufrm].userBtn.$usr $v1
+	markButton [$this net] [$this ufrm].userBtn.$usr $v1
 	markEntry $w.users.menu [indexHack $w.users.menu [$usr name] 3] $v1
 	$this cmdState
     }
@@ -1541,7 +1560,9 @@ proc wsortIns {chan win un usr} {
 #
 proc channel_addUser {this usr op sp} {
     upvar #0 $this cdata
+    lclTrace $this Op,$usr
     set cdata(Op,$usr) $op
+    lclTrace $this Spk,$usr
     set cdata(Spk,$usr) $sp
     set net $cdata(net)
     set w $cdata(window)
@@ -1557,8 +1578,8 @@ proc channel_addUser {this usr op sp} {
 	    set jn 0
 	}
 	$wnk configure -state normal
-	if {$op} { markButton $wnk operator } \
-	elseif {$sp} { markButton $wnk speaker } { markButton $wnk {} }
+	if {$op} { markButton $net $wnk operator } \
+	elseif {$sp} { markButton $net $wnk speaker } { markButton $net $wnk {} }
     }
     catch {
 	set w $w.users.menu
@@ -1598,10 +1619,9 @@ proc channel_ircOp {this state} {
 #
 proc channel_userMode {this usr mode} {
     upvar #0 $this cdata
-    switch -exact -- $mode \
-      o {set val [$this isOp $usr] ; set typ Op} \
-      v {set val [$this isSpeaker $usr] ; set typ Spk}
-#    set cdata($typ,$usr) [expr {!$val}]
+    switch -- $mode o {set typ Op} v {set typ Spk}
+    set val $cdata(lcl$typ,$usr)
+    set cdata(lcl$typ,$usr) [expr {!$val}]
     [$this net] MODE [$this name] [expr {$val ? {+} : {-}}]$mode [$usr name]
 }
 #
@@ -1625,8 +1645,8 @@ proc channel_mode {this vals prefix} {
 	switch {} $nxt {
 	    set nxt {}
 	    foreach m [split $par {}] {
-		switch -glob -- $m {
-		[+-] { set flag $m }
+		switch -- $m {
+		- - + { set flag $m }
 		l {
 			switch + $flag {append nxt $flag$m} default {
 			    set cdata(limit) {}
@@ -1634,7 +1654,7 @@ proc channel_mode {this vals prefix} {
 			    handleOn $net MODE [list [$this name] -$m]
 			}
 		    }
-		[bkov] { append nxt $flag$m }
+		b - k - o - v { append nxt $flag$m }
 		a {
 			set w $cdata(window)
 			if {[set cdata(a) [string match + $flag]]} {
@@ -1648,6 +1668,7 @@ proc channel_mode {this vals prefix} {
 			    }
 			    $net qSend NAMES :[$this name]
 			}
+			# set cdata(lcla) $cdata(a)
 			handleOn $net MODE [list [$this name] ${flag}a]
 		    }
 		m {
@@ -1656,17 +1677,20 @@ proc channel_mode {this vals prefix} {
 			} {
 			   set mt {}
 			} 
+			# set cdata(lclm) $cdata(m)
 			$this cmdState
 			$this showFlags mod $mt
 			handleOn $net MODE [list [$this name] ${flag}m]
 		    }
-		[psin] {
+		p - s - i - n {
 			set cdata($m) [string match + $flag]
+			# set cdata(lcl$m) $cdata($m)
 			handleOn $net MODE [list [$this name] $flag$m]
 		    }
 		t   {
 			set x [string match + $flag]
 			set cdata(t) $x
+			# set cdata(lclt) $x
 			if {![$this operator]} {
 			    set st [expr {$x ? {disabled} : {normal}}]
 			    switch {} [set w $cdata(window)] {} default {
@@ -1685,9 +1709,7 @@ proc channel_mode {this vals prefix} {
 	    }
 	} default {
 	    set flag [string index $nxt 0]
-	    set m [string index $nxt 1]
-	    set nxt [string range $nxt 2 end]
-	    switch -exact -- $m {
+	    switch -- [set m [string index $nxt 1]] {
 	    o   {
 		    switch + $flag {set op markOp} default {set op unmarkOp}
 		    $this $op [set who [User :: make $cdata(net) $par]]
@@ -1710,6 +1732,7 @@ proc channel_mode {this vals prefix} {
 		    banProtect $this $prefix $flag $par
 	        }
 	    }
+	    set nxt [string range $nxt 2 end]
 	    handleOn $net MODE [list [$this name] $flag$m $par]
 	}
     }
