@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Control.tcl,v $
-# $Date: 1998/03/20 14:39:00 $
-# $Revision: 1.18.1.86 $
+# $Date: 1998/04/23 13:08:53 $
+# $Revision: 1.18.1.88 $
 #
 #
 package provide zircon 1.18
@@ -653,6 +653,7 @@ proc control_delete {this} {
     deleteFrame [MainControl] [$this net]
     [$this friends] delete
     uplevel #0 unset $this
+    rename $this {}
 }
 #
 proc control_flagSet {this flg val} {
@@ -697,3 +698,15 @@ proc ntoggleII {net win} {
 	}
     }
 }
+#
+proc control_flagNick {this} {
+    upvar #0 $this cdata
+    set cdata(nfg) [[$this window].nickname cget -foreground]
+    [$this window].nickname configure -foreground red
+}
+#
+proc control_confirmNick {this nk} {
+    upvar #0 $this cdata
+    set cdata(nickname) $nk
+    [$this window].nickname configure -foreground $cdata(nfg)
+}
