@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/DALnet.tcl,v $
-# $Date: 1997/03/04 09:14:05 $
-# $Revision: 1.18.1.1 $
+# $Date: 1998/02/09 16:56:33 $
+# $Revision: 1.18.1.2 $
 #
 package provide zircon 1.18
 #
@@ -11,7 +11,7 @@ proc irc328 {net prefix param pargs} {
     switch nil [set chn [Channel :: find $chan $net]] {
 	$net inform "Url for $chan : $param"
     } default {
-	if [$chn active] {$chn showInfo url $param}
+	if {[$chn active]} {$chn showInfo url $param}
     }
 }
 #
@@ -21,7 +21,7 @@ proc irc329 {net prefix param pargs} {
     switch nil [set chn [Channel :: find $chan $net]] {
 	$net inform "$chan created at $crt"
     } default {
-	if [$chn active] {$chn showInfo create "Created at $crt"}
+	if {[$chn active]} {$chn showInfo create "Created at $crt"}
     }
 }
 #
@@ -32,6 +32,6 @@ proc irc333 {net prefix param pargs} {
     switch nil [set chn [Channel :: find $chan $net]] {
 	$net inform "$chan topic set at $crt by $who"
     } default {
-	if [$chn active] {$chn showInfo topic "Topic set by $who at $crt"}
+	if {[$chn active]} {$chn showInfo topic "Topic set by $who at $crt"}
     }
 }
