@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Entry.tcl,v $
-# $Date: 1998/03/11 10:51:57 $
-# $Revision: 1.18.1.8 $
+# $Date: 1998/04/23 08:59:04 $
+# $Revision: 1.18.1.9 $
 #
 package provide zircon 1.18
 #
@@ -62,7 +62,8 @@ proc labelEntry {t name opts init code} {
     [expr {$t ? "emacsTEntry" : "emacsEntry"}] $name.entry -relief sunken
     $name.entry insert end $init
     grid columnconfigure $name 1 -weight 1
-    grid $name.label $name.entry -sticky ew
+    grid $name.label -sticky w
+    grid $name.entry -row 0 -column 1 -sticky ew
     bind $name.entry <Return> "notIdle %W ; $code"
     bind $name.entry <BackSpace> [bind $name.entry <Delete>]
     bind $name.entry <Control-h> [bind $name.entry <Delete>]
