@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Help.tcl,v $
-# $Date: 1998/02/18 14:12:58 $
-# $Revision: 1.18.1.8 $
+# $Date: 1998/03/20 14:39:04 $
+# $Revision: 1.18.1.9 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -18,14 +18,15 @@ proc makeHelp {win nm} {
 	$win add command -label {Sorry, not yet available.} -command {}
     } {
 	$win delete 0 end
+	set hc 0
 	foreach x $st {
 	    set tx [file tail $x]
-	    set ntx [string tolower $tx]
+	    set ntx m[incr hc]
 	    if {[file isdir $x]} {
 		$win add cascade -label $tx -menu $win.$ntx
 		if {![winfo exists $win.$ntx]} {
 		    menu $win.$ntx -tearoff 0 \
-		      -postcommand "makeHelp $win.$ntx $nm/$tx"
+		      -postcommand "makeHelp $win.$ntx [file join $nm $tx]"
 		}
 	    } { 
 		$win add command -label $tx \
