@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Ignore.tcl,v $
-# $Date: 1998/02/09 16:56:37 $
-# $Revision: 1.18.1.8 $
+# $Date: 1998/04/28 13:15:22 $
+# $Revision: 1.18.1.9 $
 #
 package provide zircon 1.18
 #
@@ -41,8 +41,7 @@ proc z_ignore {usr nm} {
 proc ignoreSet {lst what} { return [expr {[lsearch $lst $what] >= 0}] }
 #
 proc ignoreFlag {lst what} {
-    set nk [lindex $lst 0]
-    set v [lindex $lst 1]
+    foreach {nk v} $lst break 
     if {[set x [lsearch $v $what]] < 0} {
 	return [list $nk [lappend v $what]]
     }
@@ -64,8 +63,7 @@ proc flipIgnore {usr what} {
 proc ignoreAll {usr} {
     global zircon IFlag
     set lst [z_ignore $usr *@*]
-    foreach x $zircon(ignore) {
-	set lx [string tolower $x]
+    foreach lx [string tolower $zircon(ignore)] {
 	if {![ignoreSet $lst $lx]} {
 	    flipIgnore $usr $lx
 	    set IFlag($usr,$lx) 1
@@ -73,9 +71,17 @@ proc ignoreAll {usr} {
     }
 }
 #
+proc ignoreRemove {net ptn} {
+    set ign {}
+    foreach x [$net ignores] {
+        switch -- $ptn [lindex $x 0] {} default { lappend ign $x }
+    }
+    $net configure -ignores $ign +confChange Ignores
+}
+#
 proc ignoreClear {usr} {
     global zircon IFlag
-    foreach x $zircon(ignore) { set IFlag($usr,[string tolower $x]) 0}
+    foreach x [string tolower $zircon(ignore)] { set IFlag($usr,$x) 0}
     set net [$usr net]
     set nk [$usr name]
     switch {} [set nm [$usr id]] { set nm *@* }
