@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Info.tcl,v $
-# $Date: 1998/04/15 12:16:08 $
-# $Revision: 1.18.1.36 $
+# $Date: 1998/04/21 12:54:46 $
+# $Revision: 1.18.1.37 $
 #
 package provide zircon 1.18
 #
@@ -19,11 +19,12 @@ proc MainInfo {} {
 }
 #
 proc Info {args} {
-    global BF Fg Bg Ft Bl OType defChan zInfo zII zNOII
+    global BF Fg Bg Ft Bl OType defChan zInfo zII zNOII zInfo
     set name [makeObj {Channel Info} $args]
     upvar #0 $name idata
     set net $idata(net)
     set w [switchFrame [MainInfo] $name [$net name] -handles]
+    $zInfo register $name {} "deleteFrame [MainInfo] $name"
     set df [getDefault defChan $net]
     $name configure -hpos 0 -open [$idata(net) popInfo] \
       -close [$df close] -jump 1 -quiet 0 -draw 0 \
