@@ -1,14 +1,17 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Log.tcl,v $
-# $Date: 1998/02/26 15:51:17 $
-# $Revision: 1.18.1.15 $
+# $Date: 1998/04/23 08:59:06 $
+# $Revision: 1.18.1.17 $
 #
 package provide zircon 1.18
 #
-proc logOpen {this mode save file} {
+proc logOpen {this mode save fl} {
     global openLogs openLfd openLMap
-    switch -- $file {} {return 0}
-    set file [fullName $file]
+    switch -- $fl {} {return 0}
+    if {[catch {fullName $fl} file]} {
+	tellError {} {Log File Error} "Cannot get full pathname for $fl : $file"
+	return 0
+    }
     regsub -all %n $file [[$this net] name] file
     regsub -all %c $file [$this name] file
     set t [clock seconds]
