@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Look.tcl,v $
-# $Date: 1997/05/21 08:52:37 $
-# $Revision: 1.18.1.11 $
+# $Date: 1998/02/24 14:42:45 $
+# $Revision: 1.18.1.17 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -16,6 +16,13 @@ proc getType {arg var} {
     set type {}
     while {![string match {} $arg]} {
 	switch -glob -- [set opt [lindex $arg 0]] {
+	-friends -
+	-dcclist -
+	-monitor -
+	-list -
+	-info -
+	-control -
+	-debug -
 	-channel -
 	-chat -
 	-message -
@@ -37,7 +44,7 @@ proc getType {arg var} {
 #
 proc getNet {ptn} {
     switch {} $ptn {
-	if [notDefault] {
+	if {[notDefaultNet]} {
 	    global currentNet
 	    regsub -all {[][+*\^$()|?]} [$currentNet name] {\\&} nn
 	    set ptn "^$nn\$"
@@ -75,22 +82,23 @@ proc share {args} {
 }
 #
 proc InitLook {} {
+    dispAd {Initialising look...}
     global Look DLook
     look -channel {^\\+.*$} {.*} {
-	        Info
+	        {{Info {limit create url topic}} {Flags {key mod}}}
 	        {{Control {Mode Info Action Users Quit Clear}}}
 	        {Text Users}
 	        Entry
 	    }
     look -channel {^\\&.*$} {.*} {
-	        Info
+	        {{Info {limit create url topic}} {Flags {key mod}}}
 	        {{Control {Mode Info Action Users Quit Clear}}}
 	        {Text {Users off}}
 	        Entry
 	    }
     look -channel {.*} {.*} {
 		Topic
-	        Info
+	        {{Info {limit create url topic}} {Flags {key mod}}}
 	        {{Control {Mode Info Action Users Quit Clear}}}
 	        {Text Users}
 	        Entry
@@ -129,22 +137,21 @@ proc findLook {id name net} {
 #
 proc findStyle {id name net} {
     global Share
-    set wnm {}
     set style original
-    if ![$id noshare] {
+    if {![$id noshare]} {
 	foreach x [array names Share] {
 	    set type [lindex $Share($x) 1]
 	    set cptn [lindex $Share($x) 2]
 	    set nptn [lindex $Share($x) 3]
 	    if {[regexp -nocase $type [$id type]] &&
 	      [regexp -nocase $cptn $name] && [regexp -nocase $nptn $net]} {
-	        if [lindex $Share($x) 4] { set style hicaffiene } {set style diet}
-	        set wnm $x
+	        if {[lindex $Share($x) 4]} { set style hicaffiene } {set style diet}
+	        return [list $style .$x]
 	        break
 	    }
 	}
     }
-    return [list $style $wnm]
+    return [list $style .$id]
 }
 #
 proc cnvType {desc ty} {
@@ -160,10 +167,10 @@ proc saveLook {desc net} {
 	    set type [lindex $Look($x) 1]
 	    set cptn [lindex $Look($x) 2]
 	    set nptn [lindex $Look($x) 3]
-	    if $cm { puts $desc "#\n# Layout control\n#" ; set cm 0 }
+	    if {$cm} { puts $desc "#\n# Layout control\n#" ; set cm 0 }
 	    puts -nonewline $desc look
 	    cnvType $desc $type
-	    if [string match -* $cptn] { puts -nonewline $desc -- }
+	    if {[string match -* $cptn]} { puts -nonewline $desc -- }
 	    puts -nonewline $desc " {$cptn}"
 	    switch -- [subst $nptn] [$net name] {} default {
 		puts -nonewline " $nptn"
@@ -182,11 +189,11 @@ proc saveShare {desc net} {
 	    set type [lindex $Share($x) 1]
 	    set cptn [lindex $Share($x) 2]
 	    set nptn [lindex $Share($x) 3]
-	    if [lindex $Share($x) 4] { set pc merge } { set pc share }
-	    if $cm { puts $desc "#\n# Window Sharing\n#" ; set cm 0 }
+	    if {[lindex $Share($x) 4]} { set pc merge } { set pc share }
+	    if {$cm} { puts $desc "#\n# Window Sharing\n#" ; set cm 0 }
 	    puts -nonewline $desc $pc
 	    cnvType $desc $type
-	    if [string match -* $cptn] { puts -nonewline $desc -- }
+	    if {[string match -* $cptn]} { puts -nonewline $desc -- }
 	    puts -nonewline $desc " {$cptn}"
 	    switch [subst $nptn] [$net name] {} default {
 		puts -nonewline $desc " $nptn"
