@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Monitor.tcl,v $
-# $Date: 1998/03/11 10:52:01 $
-# $Revision: 1.18.1.15 $
+# $Date: 1998/04/27 11:46:02 $
+# $Revision: 1.18.1.16 $
 #
 package provide zircon 1.18
 #
@@ -42,7 +42,7 @@ proc monitor_update {this names} {
 	    }
 	    listkill xist $usr
 	}
-	markButton $winu $mrk
+	markButton $net $winu $mrk
     }
     foreach n $xist {if {[normal $w.usr.$n]} {destroy $w.usr.$n ; $n deref}}
 }
