@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Net.tcl,v $
-# $Date: 1998/03/18 13:02:52 $
-# $Revision: 1.18.1.131 $
+# $Date: 1998/04/29 11:45:48 $
+# $Revision: 1.18.1.136 $
 #
 package provide zircon 1.18
 #
@@ -50,7 +50,8 @@ proc net_channelList {this chn} {
     $this configure -allChannels {} -showlist 0
     [set lst [$this listid]] show
     switch {} $chn {} default {
-	$lst doit $chn
+    	$lst configure -channel $chn
+	$lst doit
 	$this configure -showlist 1
     }
 }
@@ -279,53 +280,67 @@ proc net_startIRC {this srv args} {
     set ctl [$this control]
     set ost [$ctl openState]
     set ports [$srv port]
-    switch {} $args {} default {
+    set noret 0
+    switch -- $args {} {} -noretry { set noret 1} default {
 	switch [set pt [lindex $args 0]] [lindex $ports 0] {} default {
 	   set ports $pt
 	}
     }
     set enc [$srv encoding]
-    foreach port $ports {
-	$ctl showServer $srv $port
-	$this inform "Connecting to port $port of server $server"
-	update idletasks
-	$this slow
-	set ndata(sock) {}
-	set scmd socket
-	foreach x {myaddr myport } {
-	    switch {} $ndata($x) {} default {
-		append scmd " -$x $ndata($x)"
+    while {1} {
+	foreach port $ports {
+	    $ctl showServer $srv $port
+	    $this inform "Connecting to port $port of server $server"
+	    update idletasks
+	    $this slow
+	    set ndata(sock) {}
+	    set scmd socket
+	    foreach x {myaddr myport } {
+		switch {} $ndata($x) {} default {
+		    append scmd " -$x $ndata($x)"
+		}
+	    }
+	    append scmd " -async $server $port"
+	    if {[catch {eval $scmd} sock]} {
+		$this errmsg "Cannot connect to port $port of server $server ($sock)"
+		set ndata(sock) {}
+		$this fast
+		update
+		set rtc 2
+		continue
+	    }
+	    $this fast
+	    fileevent $sock writable "sconf $sock [list $enc]; $this afterCon $sock"
+	    $ctl setQuit abort "$this abort $sock"
+	    set connected($this) 0
+	    vwait connected($this)
+	    set rtc $connected($this)
+	    unset connected($this)
+	    if {$rtc < 2} {
+		$ctl setQuit close "$this quit"
+		return 1
+	    }
+	    $ctl setQuit open "$ctl open"
+	    $ctl setOpen $ost
+	    if {$rtc == 2} {
+	    	$this inform {Connection attempt failed}
+		retitleFrame [MainControl] $this [$this name] 1
+		retitleFrame [MainInfo] [$this info] [$this name] 1
+	    } {
+	    	$this inform {Connection attempt aborted}
+		retitleFrame [MainControl] $this [$this name]
+		retitleFrame [MainInfo] [$this info] [$this name]
 	    }
 	}
-	append scmd " -async $server $port"
-	if {[catch {eval $scmd} sock]} {
-	    $this errmsg "Cannot connect to port $port of server $server ($sock)"
-	    set ndata(sock) {}
-	    $this fast
-	    update
-	    continue
-	}
-	$this fast
-	fileevent $sock writable \
-	  "sconf $sock [list $enc]; $this cCheck $sock ; $this afterCon $sock"
-	$ctl setQuit abort "$this abort $sock"
-	set connected($this) 0
-	vwait connected($this)
-	if {[set res [expr {$connected($this) < 2}]]} {
-	    $ctl setQuit close "$this quit"
-	    return $res
-	}
-	$ctl setQuit open "$ctl open"
-	$ctl setOpen $ost
-	if {$connected($this) == 2} {
-	    retitleFrame [MainControl] $this [$this name] 1
-	    retitleFrame [MainInfo] [$this info] [$this name] 1
-	} {
-	    retitleFrame [MainControl] $this [$this name]
-	    retitleFrame [MainInfo] [$this info] [$this name]
+	$ctl showServer $srv [lindex $ports 0]
+	if {$noret} { return 0}
+	if {$rtc == 2} {
+	    if {![askUser NOCON [trans connect] \
+	      "Cannot connect to any ports of $server.\nTry again?"]} {
+	        return 0
+	    }
 	}
     }
-    return 0
 }
 #
 proc net_abort {this sock} {
@@ -333,11 +348,6 @@ proc net_abort {this sock} {
     uplevel #0 set connected($this) 3
 }
 #
-proc net_cCheck {this sock} {
-    uplevel #0 set connected($this) 1
-    fileevent $sock writable {}
-}
-#
 proc net_getIrcname {this} {
     upvar #0 $this ndata
     global user host
@@ -349,6 +359,7 @@ proc net_getIrcname {this} {
 #
 proc net_afterCon {this sock} {
     global user host STN DEBUG
+    fileevent $sock writable {}
     upvar #0 $this ndata
     set STN($sock) $this
     set ndata(sock) $sock
@@ -357,17 +368,29 @@ proc net_afterCon {this sock} {
     if {![info exists host]} {set host [info hostname]}
     set server [$srv host]
     set passwd [$srv passwd]
-    foreach ln [$srv script] { puts -nonewline $sock "$ln\n" }
+    foreach ln [$srv script] {
+        if {[catch {puts -nonewline $sock "$ln\n"}]} {
+	    return
+	}
+    }
     fileevent $sock readable "ircInput r $sock" 
-    switch {} $passwd {} default {$this qSend PASS :$passwd}
-    $this qSend USER $user $host $server :[$this getIrcname]
-    $this qSend NICK $ndata(nickname)
+    switch {} $passwd {} default {
+        if {[$this qSend PASS :$passwd]} { return }
+    }
+    if {[$this qSend USER $user $host $server :[$this getIrcname]]} {
+	# not connected....
+	return
+    }
+    if {[$this qSend NICK $ndata(nickname)]} {
+	# connection dropped after USER
+	return
+    }
+    uplevel #0 set connected($this) 1
     if {!$ndata(noRefresh)} { $this channelList { } }
     retitleFrame [MainInfo] [$this info] [set msg "[$this name] - [$this host]"] 1
     retitleFrame [MainControl] $this $msg 1
     $this configure -startup 1
     if {$DEBUG} { zDBGRet $this }
-    return 1
 }
 #
 proc net_changeServerPort {this srv prt} {
@@ -413,10 +436,10 @@ proc net_deIRCOp {this} {
 proc net_setNickname {this nk} {
     set nk [$this trimNick $nk]
     upvar #0 $this ndata
-    catch {$ndata(control) configure -nickname $nk}
+    catch {$ndata(control) confirmNick $nk}
     set ndata(nickname) $nk
     switch nil [set myid [$this myid]] {} default {
-        switch -- [$myid name] $nk {} default {
+	switch -- [$myid name] $nk {} default {
 	    foreach x {channels messages notices chats} {
 		foreach id [$this $x] { $id nickChange $myid $nk }
 	    }
@@ -429,7 +452,10 @@ proc net_setNickname {this nk} {
 proc net_changeNickname {this nk} {
     if {[$this active]} {
 	$this NICK $nk
-	$this configure -nickwait 1
+	if {![$this nickwait]} {
+	    [$this control] flagNick 
+	    $this configure -nickwait 1
+	}
     } { $this setNickname $nk }
 }
 #
@@ -456,7 +482,11 @@ proc net_close {this args} {
     global zircon connected
     catch {destroy .@ne$this}
     upvar #0 $this ndata
-    set connected($this) 2
+    set start 0
+    if {[info exists connected($this)]} {
+	set connected($this) 2
+	set start 1
+    }
     set qmsg {}
     set recon [$this active]
     switch nil [set srv $ndata(hostid)] {
@@ -464,7 +494,7 @@ proc net_close {this args} {
 	set port 6667
     } default {
 	set host [$srv host]
-	set port [$srv port]
+	set port [[$this control] port]
     }
     switch [llength $args] {
     2 {set msg {} ; switch {} [set qmsg [lindex $args 0]] { set qmsg { }}; set recon 0}
@@ -479,21 +509,23 @@ proc net_close {this args} {
 	foreach id $ndata($x) { $id flag disabled }
     }
     $this irc305
-    set zircon(j) 0
-    handleOn $this CLOSE [list $host $port]
-    if {$recon} {
-	bell
-	if {[$this reconnect]} {startReconn $this $srv $msg} \
-	elseif {[$this srvcycle]} {
-	    set s $ndata(servers)
-	    set pos [lsearch $s $srv]
-	    incr pos
-	    switch {} [set srv [lindex $s $pos]] {set srv [lindex $s 0]}
-	    after 0 $this doReconnect $srv
-	} {
-	    if {[listmember [$this alwayslog] CLOSE]} {$this inform $msg}
-	    if {[askUser SHUT [trans shutdown] "$msg\nReconnect?"]} {
+    if {!$start} {
+	set zircon(j) 0
+	handleOn $this CLOSE [list $host $port]
+	if {$recon} {
+	    bell
+	    if {[$this reconnect]} {startReconn $this $srv $msg} \
+	    elseif {[$this srvcycle]} {
+		set s $ndata(servers)
+		set pos [lsearch $s $srv]
+		incr pos
+		switch {} [set srv [lindex $s $pos]] {set srv [lindex $s 0]}
 		after 0 $this doReconnect $srv
+	    } {
+		if {[listmember [$this alwayslog] CLOSE]} {$this inform $msg}
+		if {[askUser SHUT [trans shutdown] "$msg\nReconnect?"]} {
+		    set ndata(reconaft) [after 5000 $this doReconnect $srv]
+		}
 	    }
 	}
     }
@@ -512,14 +544,16 @@ proc startReconn {net srv msg} {
 proc stopReconn {this} {
     upvar #0 $this ndata
     if [info exists $ndata(reconaft)] {
-        catch {after cancel $ndata(reconaft)}
-        unset ndata(reconaft)
+	catch {after cancel $ndata(reconaft)}
+	unset ndata(reconaft)
     }
 }
 #
 proc net_doReconnect {this srv} {
-    if {![$this startIRC $srv] && [$this reconnect]} {
-	after 0 startReconn $this $srv {{}}
+    upvar #0 $this ndata
+    catch {unset ndata(reconaft)}
+    if {![$this startIRC $srv [$ndata(control) port]] && [$this reconnect]} {
+	set ndata(reconaft) [after 5000 startReconn $this $srv {{}}]
     }
 }
 #
@@ -821,6 +855,7 @@ proc net_delete {this} {
     global znetList
     safeUnset [list XTO([string tolower [$this name]])] OType($this) $this
     listkill znetList $this
+    rename $this {}
 }
 #
 proc net_squery {this} {
@@ -864,14 +899,14 @@ proc net_clearMsgs {this usrs} {
 #
 proc net_fileProcess {this file usr} {
     foreach x [$this helpers] {
-        if {[regexp [lindex $x 0] $file]} {
+	if {[regexp [lindex $x 0] $file]} {
 	    set cmd [lindex $x 1]
 	    set np [lindex $x 2]
 	    if {[regexp -nocase $np [$usr name]]} {
-	        regsub -all %s $cmd $file cmd
-	        if {[catch {eval exec $cmd &} msg]} {
+		regsub -all %s $cmd $file cmd
+		if {[catch {eval exec $cmd &} msg]} {
 	    	    tellError {} Error "Error executing helper cmd $cmd - $msg"
-	        }
+		}
 		return
 	    }
 	}
