@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Netspace.tcl,v $
-# $Date: 1997/05/16 09:41:52 $
-# $Revision: 1.18.1.16 $
+# $Date: 1998/02/23 09:21:24 $
+# $Revision: 1.18.1.20 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -14,7 +14,7 @@ package provide zircon 1.18
 proc Netspace {name args} {
     global currentNet
     switch {} $currentNet {} default {
-	if [notDefaultNet] { error "Nested Netspace directive for $name."}
+	if {[notDefaultNet]} { error "Nested Netspace directive for $name."}
     }
     nsLoad $name 0 $args
 }
@@ -22,23 +22,23 @@ proc Netspace {name args} {
 proc nsLoad {name show opts} {
     global XTO currentNet DEBUG zircon
     set f [file join $zircon(prefdir) netspaces $name]
-    if ![file exists $f] {
+    if {![file exists $f]} {
 	tellError {} Netspace "Cannot find Netspace $name"
 	return 0
     }
-    if [file isdirectory $f] {
+    if {[file isdirectory $f]} {
 	set f [file join $f preferences]
-	if ![file exists $f] {
+	if {![file exists $f]} {
 	    tellError {} Netspace "Cannot find Netspace preferences for $name"
 	    return 0
 	}
     }
     set ln [string tolower $name]
-    if [info exists XTO($ln)] {
+    if {[info exists XTO($ln)]} {
 	for {set i 1} {[info exists XTO($ln$i)]} {incr i} {}
 	set nn1 $name$i
-	if ![askUser {} {Netspace Load} "Netspace \"$name\" is already loaded.\
-It will be loaded under the name \"$nn1\"."] return
+	if {![askUser {} {Netspace Load} "Netspace \"$name\" is already loaded.\
+It will be loaded under the name \"$nn1\"."]} return
 	addToNM $nn1
     } {
 	set nn1 $name
@@ -46,24 +46,24 @@ It will be loaded under the name \"$nn1\"."] return
     set sc $currentNet
     set currentNet [Net $nn1]
     makeDefaults $currentNet
-    if [catch {source $f} msg] {
+    if {[catch {source $f} msg]} {
 	tellError {} {Netspace error} "Error in netspace $nn1 - $msg"
     } {
 	InitNet $currentNet
 	$currentNet show
-	if $show {
-	    exposeFrame .@ctl $currentNet
-	    exposeFrame .@inf [$currentNet info]
+	if {$show} {
+	    exposeFrame [MainControl] $currentNet
+	    exposeFrame [MainInfo] [$currentNet info]
 	}
-	if $DEBUG { zDBGAdd $currentNet }
+	if {$DEBUG} { zDBGAdd $currentNet }
     }
     set currentNet $sc
     setUnload $nn1 normal
 }
 #
 proc nsDelete {name} {
-    if ![askUser {} {Delete Netspace} \
-       "Are you sure you want to delete Netspace \"$name\""] return
+    if {![askUser {} {Delete Netspace} \
+       "Are you sure you want to delete Netspace \"$name\""]} return
     global zircon
     filedirdel [file join $zircon(prefdir) netspaces $name]
     delFromNsM $name
@@ -87,8 +87,8 @@ proc nsAddClone {old new} {
     set dir [file join $zircon(prefdir) netspaces]
     set of [file join $dir $old]
     set nf [file join $dir $new]
-    if [file isdirectory $of] {
-	if [catch {filemkdir $nf} msg] {
+    if {[file isdirectory $of]} {
+	if {[catch {filemkdir $nf} msg]} {
 	    tellError {} "Clone Error" $msg
 	    return
 	}
@@ -96,7 +96,7 @@ proc nsAddClone {old new} {
 	    filecopy $x $nf
 	}
     } {
-	if [catch {filecopy $of $nf} msg] {
+	if {[catch {filecopy $of $nf} msg]} {
 	    tellError {} "Clone Error" $msg
 	}
     }
@@ -107,7 +107,12 @@ proc nsUnload {name} {
     global zircon
     foreach x [Net :: list] {
 	switch -- [$x name] $name {
-	    if ![file exists [file join $zircon(prefdir) netspaces $name]] {
+	    switch {} [$x sock] {} default {
+	    	tellInfo $x {Active Netspace} "Netspace $name is active. Please\
+		close the connection before trying to unload it."
+		return
+	    }
+	    if {![file exists [file join $zircon(prefdir) netspaces $name]]} {
 		delFromNsM [$x name]
 	    } {
 		setUnload $name disabled
