@@ -1,27 +1,25 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Server.tcl,v $
-# $Date: 1997/05/30 13:33:43 $
-# $Revision: 1.18.1.20 $
+# $Date: 1998/02/27 10:35:59 $
+# $Revision: 1.18.1.27 $
 #
 #
 package provide zircon 1.18
 #
 proc Server {name args} {
     switch -- $name :: {return [eval Server_[lindex $args 0] [lrange $args 1 end]]}
-    set this [objName Server]
-    initObj $this Server
-    global currentNet
-    upvar #0 STO$currentNet STO $this sdata
     switch -glob -- $name -* {
 	set args [linsert $args 0 $name]
 	set name [newName _srv]
     }
-    set sdata(name) $name
-    set sdata(host) $name
-    set sdata(net) $currentNet
+    set this [makeObj Server $args]
+    global currentNet
+    upvar #0 STO$currentNet STO $this sdata
+    array set sdata "
+	name	[list $name]
+	net	$currentNet
+    "
     $currentNet register servers $this
-    proc $this {args} "eval server_call $this \$args"
-    eval $this configure $args
     switch -- $sdata(name) $sdata(host) {set sdata(name) [newName _srv]}
     set STO([string tolower $sdata(name)]) $this
     return $this
@@ -29,14 +27,17 @@ proc Server {name args} {
 #
 proc server_configure {this args} {
     upvar #0 $this sdata
-    while {![string match {} $args]} {
-	set opt [lindex $args 0]
-	set val [lindex $args 1]
+    foreach {opt val} $args {
 	switch -exact -- $opt {
 	-port {
 		set sdata(port) {}
 		foreach x $val {
-		    if [regexp {^([0-9]+)-([0-9]+)$} $x m st fn] {
+		    if {[regexp {^([0-9]+)-([0-9]+)$} $x m st fn]} {
+			if {$fn < $st} {
+			    set a $fn
+			    set fn $st
+			    set st $a
+			}
 			for {} {$st <= $fn} {incr st} {
 			    lappend sdata(port) $st
 			}
@@ -44,21 +45,19 @@ proc server_configure {this args} {
 			lappend sdata(port) $x
 		    }
 		}
+		set sdata(port) [lsort -integer $sdata(port)]
 	    }
 	-host { set sdata(host) [string tolower $val] }
-	default {
-		set sdata([string range $opt 1 end]) $val
-	    }
+	default { set sdata([string range $opt 1 end]) $val }
 	}
-	set args [lrange $args 2 end]
     }
 }
 #
-proc server_call {this op args} {
-   upvar #0 $this sdata
-   if [info exists sdata($op)] { return $sdata($op) }
-   return [eval server_$op $this $args ]
-}
+#proc server_call {this op args} {
+#   upvar #0 $this sdata
+#   if {[info exists sdata($op)]} { return $sdata($op) }
+#   return [eval server_$op $this $args ]
+#}
 #
 proc server_delete {this} {
     uplevel #0 unset STO\${currentNet}([string tolower [$this name]]) $this
@@ -79,40 +78,40 @@ proc Server_save {desc net} {
     set cm 1
     set sid 1
     foreach id [$net servers] {
-	if [$id sys] continue
+	if {[$id sys]} continue
 	set n [$id name]
 	set nmap($n) $sid
 	switch default $n continue
 	set ln [list Server -host [$id host]]
 	switch 6667 [set pl [$id port]] {} default {
 	    if {[llength $pl] > 1} {
-		set start {}
-		foreach x $pl {
-		    switch {} $start {
-			append npl " $x"
-			set start $x
-			incr start
-		    } default {
-			switch $start $x {incr start} default {
-			    append npl "-[incr start -1] "
-			    set start {}
+		set lst [set start [lindex $pl 0]]
+		set npl $start
+		foreach x [lrange $pl 1 end] {
+		    switch [incr start] $x {} default {
+		    	incr start -1
+			switch $start $lst {
+			    append npl " $x"
+			} default {
+			    append npl "-$start $x"
 			}
+			set lst [set start $x]
 		    }
 		}
-		switch {} $start {} default {
-		   append npl "-[incr start -1]"
+		switch $lst $start {} default {
+		    append npl "-$start"
 		}
-		set pl [string trim $npl]
+		set pl "{$npl}"
 	    }
 	    append ln " -port $pl"
 	}
 	foreach x {oper operpw script passwd} {
 	    switch {} [set y [$id $x]] {} default {append ln " -$x [list $y]"}
 	}
-	foreach x {invisible wallops srvmsg} {
-	    if [$id $x] { append ln " -$x 1" }
+	foreach x {invisible wallops srvmsg undernet} {
+	    if {[$id $x]} { append ln " -$x 1" }
 	}
-	if $cm { puts $desc "#\n# Servers\n#" ; set cm 0 }
+	if {$cm} { puts $desc "#\n# Servers\n#" ; set cm 0 }
 	puts $desc $ln
 	incr sid
     }
@@ -154,7 +153,7 @@ proc server_unpack {this net} {
 }
 #
 proc Server_pack {net} {
-    foreach s [$net servers] { if ![$s sys] { $s pack $net} }
+    foreach s [$net servers] { if {![$s sys]} { $s pack $net} }
 }
 #
 proc Server_unpack {net} {
@@ -168,7 +167,7 @@ proc Server_cleanup {where} { }
 proc Server_find {name net} {
     upvar #0 STO$net STO
     set name [string tolower $name]
-    if [info exists STO($name)] { return $STO($name) }
+    if {[info exists STO($name)]} { return $STO($name) }
     foreach x [array names STO] {
 	switch -- [$STO($x) host] $name {return $STO($x)}
     }
