@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Tracing.tcl,v $
-# $Date: 1998/02/24 11:52:55 $
-# $Revision: 1.18.1.28 $
+# $Date: 1998/04/29 11:44:30 $
+# $Revision: 1.18.1.30 $
 #
 #
 package provide Tracing 1.18
@@ -71,27 +71,34 @@ proc net_send {this op args} {
 	}
     }
     zOut $msg $this
-    if {[catch {puts $ndata(sock) $msg} err]} { $this close $err}
+    if {[catch {puts $ndata(sock) $msg} err]} { $this close $err ; return 1}
+    return 0
 }
 #
 proc net_qSend {this op args} {
     upvar #0 $this ndata
     set msg "$op [join $args]"
     zOut $msg $this
-    if {[catch {puts $ndata(sock) $msg} err]} { $this close $err}
+    if {[catch {puts $ndata(sock) $msg} err]} {
+        $this close $err
+	return 1
+    }
+    return 0
 }
 #
 proc net_sendRaw {this value} {
     zOut $value $this
     upvar #0 ${this}(sock) sock
     switch {} $sock return
-    if {[catch {puts $sock $value} msg]} {$this close $msg}
+    if {[catch {puts $sock $value} msg]} {$this close $msg ; return 1}
+    return 0
 }
 #
 proc net_q1Send {this op} {
     upvar #0 $this ndata
     zOut $op $this
-    if {[catch {puts $ndata(sock) $op} err]} { $this close $err}
+    if {[catch {puts $ndata(sock) $op} err]} { $this close $err ; return 1}
+    return 0
 }
 #
 proc connect {host port} {
@@ -112,7 +119,7 @@ proc net_doClose {this sock} {
     zOut "**** Closing connection on $sock" $this
     if {[catch {close $sock} msg]} { zOut "Error closing $sock - $msg" $this }
     switch $sock $ndata(sock) {
-	$this inform "Connection to [$this host] closed"
+	$this inform "Disconnected from [$this host]"
     }
     switch {} $ndata(closing) {} default {
 	catch {after cancel $ndata(closing)}
