@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Undernet.tcl,v $
-# $Date: 1997/06/07 13:14:28 $
-# $Revision: 1.18.1.10 $
+# $Date: 1998/02/09 16:56:54 $
+# $Revision: 1.18.1.11 $
 #
 package provide zircon 1.18
 #
@@ -22,7 +22,7 @@ proc irc006 {net prefix param pargs} {
 #
 proc irc007 {net prefix param pargs} {
     global umap
-    if ![winfo exists [set w .@map$net]] {
+    if {![winfo exists [set w .@map$net]]} {
 	toplevel $w -class Zircon
 	wm title $w "Undernet Map from [$net host]"
 	wm resizable $w 1 1
@@ -113,7 +113,7 @@ proc irc249 {net prefix param pargs} {
 }
 #
 proc underflags {net} {
-    if [winfo exists [set w .@und$net]] { popup $w ; return }
+    if {[winfo exists [set w .@und$net]]} { popup $w ; return }
     global underflags zircon
     toplevel $w -class Zircon
     wm title $w "Server message flags for [$net name]"
