@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Unix.tcl,v $
-# $Date: 1997/02/28 13:36:28 $
-# $Revision: 1.18.1.4 $
+# $Date: 1998/02/09 16:56:55 $
+# $Revision: 1.18.1.5 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -14,7 +14,7 @@ package provide unix 1.18
 #
 proc tmpdir {} {
     global zircon
-    if [info exists zircon(tmp)] { return $zircon(tmp) }
+    if {[info exists zircon(tmp)]} { return $zircon(tmp) }
     return /tmp
 }
 #
@@ -22,8 +22,8 @@ proc prefdir {} { return [file join [glob ~] .zircon] }
 #
 proc username {} {
     global env
-    if [info exists env(USER)] { return $env(USER) }
-    if [catch {set w [exec whoami]}] {
+    if {[info exists env(USER)]} { return $env(USER) }
+    if {[catch {set w [exec whoami]}]} {
 	set w [lindex [exec who am i] 0]
     }
     return $w
