@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/User.tcl,v $
-# $Date: 1998/03/03 09:28:18 $
-# $Revision: 1.18.1.39 $
+# $Date: 1998/04/15 12:56:08 $
+# $Revision: 1.18.1.42 $
 #
 package provide zircon 1.18
 #
@@ -113,10 +113,12 @@ proc user_mode {this mode args} {
 }
 #
 set zFileTypes {
-  {{All Files} {.*}}
-  {{Gif Images} {.\[gG\]\[iI\]\[fF\]} GIFF}
-  {{JPEG Images} {.\[jJ\]\[pP\]\[eE\]?\[gG\]} JFIF}
-  {{Wav Sounds} {.\[wW\]\[aA\]\[vV\]}}
+  {{All Files}		{*}				}
+  {{Gif Images}		{.gif .GIF}			}
+  {{Gif Images}		{}				GIFF}
+  {{JPEG Images}	{.jpg .JPG .jpeg .JPEG}		}
+  {{JPEG Images}	{}				JFIF}
+  {{Wav Sounds}		{.wav .WAV}			}
 }
 #
 proc user_heal {this} {
@@ -156,6 +158,25 @@ proc user_heal {this} {
 #
 proc user_kill {this} { kill [$this net] [$this name] }
 #
+proc user_protect {this chan culprit mode} {
+    switch [set frd [$this fobj]] nil return
+    if {[string match :* $culprit]} {
+        set culprit [string range $culprit 1 end]
+    }
+    set nm [$chan name]
+    foreach x [$frd protect] {
+	if {[regexp -nocase [lindex $x 0] $nm]} {
+	    foreach y [lindex $x 1] {
+	        if {[regexp -- [lindex $y 0] $mode]} {
+		    friendAction $this $chan $culprit [lindex $y 1]
+		    culpritAction $culprit $this $chan [lindex $y 2]
+		    return
+		}
+	    }
+	}
+    }
+}
+#
 proc user_pack {this net} {
     upvar #0 ${net}UTO newt
     uplevel #0 array set new$this \[array get $this\]
