@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Util.tcl,v $
-# $Date: 1998/03/05 09:11:16 $
-# $Revision: 1.18.1.62 $
+# $Date: 1998/04/27 11:46:05 $
+# $Revision: 1.18.1.65 $
 #
 package provide zircon 1.18
 #
@@ -199,12 +199,12 @@ proc postUM {chid win usr} {
 	    switch $cmd {
 	    Speak {
 		$win add checkbutton -label [trans speak] \
-		  -variable ${chid}(Spk,$usr) \
+		  -variable ${chid}(lclSpk,$usr) \
 		  -command "$chid userMode $usr v" -state $st
 	      }
 	    ChanOp {
 		$win add checkbutton -label [trans chanop] \
-		  -variable ${chid}(Op,$usr) \
+		  -variable ${chid}(lclOp,$usr) \
 		  -command "$chid userMode $usr o" -state $st
 	      }
 	    Kick -
@@ -380,7 +380,7 @@ proc hideFrame {ctl net} {
 proc deleteFrame {ctl net} {
      array set ginf [grid info $ctl.$net]
      destroy $ctl.$net
-     grid rowconfigure $ctl $ginf(-row) -weight 0
+     grid rowconfigure $ctl $ginf(-row) -weight 0 -minsize 0
 }
 #
 proc makeMB {win text} {
@@ -465,7 +465,16 @@ proc popup {win} {
     catch {[Window :: id $win] extendTime}
 }
 #
-proc markButton {name which} {
+proc checkIndicator {net win flag} {
+    if {[$net ircIIops]} {
+        set txt [$win cget -text]
+	regexp {^(@?)(\+?)(.*)} $txt m op spk txt
+        switch $flag operator { set txt @$txt } speaker { set txt +$txt }
+	$win configure -text $txt
+    }
+}
+#
+proc markButton {net name which} {
     if {![winfo exists $name]} return
     foreach {opt uopt lopt} {font Font font \
 	foreground Foreground foreground \
@@ -476,7 +485,7 @@ proc markButton {name which} {
 	switch {} [set cl [option get $name $fopt $uopt]] {
 	    switch {} $which {
 		switch {} [set cl [lindex [$name conf -$lopt] 3]] {} default {
-		    if {[catch {$name conf -$lopt $cl}]} {
+		    if {[catch {$name conf -$lopt $cl} msg]} {
 			tellError {} {Option Error} "$opt configuration error - \"$msg\""
 		    }
 		}
@@ -488,6 +497,7 @@ proc markButton {name which} {
 	} \
     }
     checkColour $name
+    checkIndicator $net $name $which
 }
 #
 proc lchange {x} {
