@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Window.tcl,v $
-# $Date: 1998/03/02 11:57:46 $
-# $Revision: 1.18.1.30 $
+# $Date: 1998/04/29 11:44:31 $
+# $Revision: 1.18.1.31 $
 #
 package provide zircon 1.18
 #
@@ -16,14 +16,22 @@ proc Window {name args} {
     upvar #0 $this wdata
     set wdata(name) $ln
     proc $this {op args} "objCall window $this \$op \$args"
-    toplevel $ln -class Zircon
+    topAndIcon $ln "$this close"
     wm resizable $ln 1 1
-    wm protocol $ln WM_DELETE_WINDOW "$this close"
     eval $this configure $args
     uplevel #0 lappend zWList $this
     return $this
 }
 #
+proc topAndIcon {win del} {
+    global zLogo
+    toplevel $win -class Zircon
+    switch {} $del {} default { wm protocol $win WM_DELETE_WINDOW $del }
+#    wm withdraw [toplevel ${win}icon]
+#    pack [label ${win}icon.label -image $zLogo]
+#    wm iconwindow $win ${win}icon
+}
+#
 proc Window_id {win} {
     global WTO
     if {[info exists WTO([set w [winfo toplevel $win]])]} { return $WTO($w) }
@@ -90,9 +98,7 @@ proc window_resetIcon {this { icnbm {} } } {
     global Icon IconBM
     set win [$this name]
     wm iconname $win "$Icon($win)"
-    if { $icnbm != {} } {
-	wm iconbitmap $win $icnbm
-    }
+    switch {} $icnbm  {} default { wm iconbitmap $win $icnbm }
     bind $win <Map> {}
 }
 #
