@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/confChan.tcl,v $
-# $Date: 1998/03/20 14:39:08 $
-# $Revision: 1.18.1.26 $
+# $Date: 1998/04/27 15:38:10 $
+# $Revision: 1.18.1.28 $
 #
 package provide zircon 1.18
 #
@@ -54,7 +54,8 @@ proc changeChan {net dbl win y} {
 }
 #
 proc setCCB {net chan args} {
-    global confB Configure.Channel
+    global Configure.Channel
+    upvar #0 confB$net confB
     set w .@conf$net.f.chld
     switch {} $chan {
 	foreach wc [winfo children $w.options] {
@@ -98,15 +99,13 @@ proc doCAC {net win posn chan} {
     set chid [Channel :: make $net $chan]
     upvar #0 new$chid newc
     set x $posn
-    if {![array exists newc]} { $chid pack new }
     if {![$chid keep]} {
 	set x [expr {[llength $lbdata($win)] - 2}]
 	set lbdata($win) [linsert $lbdata($win) $x [list $chan $chid]]
 	$chid configure -keep 1 -sys 0
     }
+    if {![array exists newc]} { $chid pack new }
     uplevel #0 "set selID($net) $chid ; lappend newChn($net) $chid"
-    set newc(keep) 1
-    set newc(sys) 0
     confSelClear $win $x
     setCCB $net $chid
     confDirty $net
@@ -166,24 +165,28 @@ proc confChannels {net win} {
     bind $wincn.l <Button-1> "changeChan $net 0 %W %y"
     bind $wincn.l <Double-Button-1> "changeChan $net 1 %W %y"
     frame $win.options
+    set i 0
+    set j 0
     foreach opt [array names Configure.Channel] {
 	switch [lindex [set ov [set Configure.Channel($opt)]] 0] bool {
-	    switch {} [set tn [lindex $ov 1]] {
-		set tn [trans $opt]
-	    }
+	    switch {} [set tn [lindex $ov 1]] { set tn [trans $opt] }
 	    checkbutton $win.options.$opt -text $tn \
 	      -variable new$defChan($net)($opt) \
 	      -command "confDirty $net"
-	    grid $win.options.$opt -sticky w
+	    grid $win.options.$opt -row $i -column $j -sticky w
+	    if {[incr j] > 2} { set j 0 ; incr i }
 	}
     }
-    label $win.options.msg -text [trans messages]
-    grid $win.options.msg -sticky w
+    label $win.options.msg -text [trans {Show Messages}]
+    grid $win.options.msg - -
+    if {$j<= 2} { incr i 2 } { incr i}
+    set j 0
     foreach opt [lindex [set Configure.Channel(msg)] 1] {
 	set val [string tolower $opt]
 	checkbutton $win.options.msg$val -text [trans $opt] \
-	  -variable confB($val) -command "doConfButton $net $val"
-	grid $win.options.msg$val -sticky w
+	  -variable confB${net}($val) -command "doConfButton $net $val"
+	grid $win.options.msg$val -row $i -column $j -sticky w
+	if {[incr j] > 2} { set j 0 ; incr i }
     }
     frame $win.values
     frame $win.look
@@ -301,8 +304,7 @@ proc saveChan {net} {
 proc doConfButton {net indx} {
     global selID
     switch nil $selID($net) return
-    global confB
-    upvar #0 new$selID($net) new
+    upvar #0 new$selID($net) new confB$net confB
     set vdx [lsearch $new(msg) [set v [string toupper $indx]]]
     if {!$confB($indx)} {
 	if {$vdx < 0} { lappend new(msg) $v }
