@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/confTab.tcl,v $
-# $Date: 1998/04/20 11:42:19 $
-# $Revision: 1.18.1.12 $
+# $Date: 1998/04/27 11:46:06 $
+# $Revision: 1.18.1.14 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -15,9 +15,12 @@ package provide zircon 1.18
 proc configWin {net} {
     global lastConf
 
+    if {[winfo exists [set w .@conf$net]]} {
+	popup $w
+	return
+    }
     set lastConf($net) Nicknames
-    set w .@conf$net
-    toplevel $w
+    toplevel $w -class Zircon
     wm title $w "Configure Netspace [$net name]"
     frame $w.btn
     foreach x {revert apply save dismiss} {
@@ -25,11 +28,11 @@ proc configWin {net} {
     }
     evenGrid $w.btn column 0 3
     grid $w.btn.revert $w.btn.apply $w.btn.save $w.btn.dismiss -sticky ew
-    canvas $w.page -highlightthickness 0 -width 300
+    canvas $w.page -highlightthickness 0 -width 350
     after idle "drawTabs $net"
     frame $w.f -relief sunken -bd 1
     grid columnconfigure $w 0 -weight 1
-    grid rowconfigure $w 1 -weight 1
+    grid rowconfigure $w 1 -weight 1 -minsize 200
     grid $w.page -sticky ew
     grid $w.f -sticky nsew
     grid $w.btn -sticky ew
@@ -72,13 +75,6 @@ proc drawTabs {net} {
 #
 proc tabShow {net pane} {
     global t option pref lastConf
-#    if {[listmember [set cc [$net confChange]] $lastConf($net)]} {
-#       if {![askUser {} {Save Changes} "You have unsaved changes for\
-# $lastConf($net) which will be lost if you change to $pane. Really\
-# change to $pane?"]} return
-#       listkill cc $lastConf($net)
-#       $net configure -confChange $cc
-#    }
     set w .@conf$net
     $w.page itemconfigure tab -fill [$w.page cget -selectbackground]
     $w.page itemconfigure tab-$pane -fill [$w.page cget -background]
@@ -139,12 +135,13 @@ proc confdismiss {net win} {
     foreach x [$net confChange] {
         confrevclean $net $x 
     }
+    safeUnset confI$net
 }
 #
 proc confrevert {net win} {
     global lastConf
     confrevclean $net $lastConf($net)
-    conf$lastConf($net) $net $win
+    tabShow $net $lastConf($net)
     confClean $net
 }
 #
