@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/config.tcl,v $
-# $Date: 1998/02/09 16:57:04 $
-# $Revision: 1.18.1.28 $
+# $Date: 1998/04/23 08:59:20 $
+# $Revision: 1.18.1.29 $
 #
 package provide zircon 1.18
 #
@@ -76,10 +76,18 @@ proc confCopyBack {net which} {
 	    Friend :: unpack $net
 	}
     Info {
+    	    global Configure.Net
 	    set win .@conf$net.f.chld
-	    set newd(notifyInterval) [expr {[$win.misc1.ison.entry get] * 1000}]
-	    set newd(listPattern) [$win.filter2.entry get]
-	    set newd(topicPattern) [$win.filter3.entry get]
+	    set cnt 0
+	    foreach {nm y} [array get Configure.Net] {
+	        switch mseconds [lindex $y 0] {
+		    switch {} [lindex $y 1] continue
+		    set newd($nm) [expr {[$win.ms.$cnt.entry get] * 1000}]
+		    incr cnt
+		}
+	    }
+	    set newd(listPattern) [$win.filter2.c.entry get]
+	    set newd(topicPattern) [$win.filter2.t.entry get]
 	}
     }
     foreach v $cVars($which) {
@@ -308,8 +316,6 @@ proc confEnt {net win var title} {
     set name [string tolower $title]
     set winn $win.$name
     frame $winn -relief raised -bd 1
-    grid rowconfigure $winn 1 -weight 1
-    grid columnconfigure $winn 0 -weight 1
     set winnl $winn.list
     makeLB $winnl -relief flat
     set lbdata($winnl.l) {}
@@ -332,7 +338,9 @@ proc confEnt {net win var title} {
     bind $winnl.l <Delete> "confDel $net $var %W"
     bind $winnl.l <BackSpace> [bind $winnl.l <Delete>]
     bind $winnl.l <Control-h> [bind $winnl.l <Delete>]
-    grid $winn.list -sticky nsew
+    grid rowconfigure $winn 1 -weight 1
+    grid columnconfigure $winn 0 -weight 1
+    grid $winnl -sticky nsew
     grid columnconfigure $win 0 -weight 1
     grid rowconfigure $win 0 -weight 1
     grid $winn -sticky nsew
