@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/dbgsrv.tcl,v $
-# $Date: 1997/06/07 13:14:33 $
-# $Revision: 1.18.1.8 $
+# $Date: 1998/02/10 10:48:40 $
+# $Revision: 1.18.1.9 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -15,7 +15,7 @@ set zircsrv {}
 #
 proc DebugServer {w} {
     global zircsrv zircon
-    if [catch {socket -server acceptIRC 6667} zircsrv] { return 0 }
+    if {[catch {socket -server acceptIRC 6667} zircsrv]} { return 0 }
     $w configure -state disabled
     set ctl [toplevel .@dbgsrv -class Zircon]
     wm title $ctl "Zircon Dummy Server"
@@ -68,7 +68,7 @@ ztest" -state disabled] -row 0 -column 1 -sticky ew
 #
 proc DSPut {w txt} {
     global zircsin
-    if ![string match :* $txt] { set txt ":[info hostname] $txt" }
+    if {![string match :* $txt]} { set txt ":[info hostname] $txt" }
     puts $zircsin $txt
     $w.txt insert end <$txt out "\n"
     $w.txt see end
@@ -96,7 +96,7 @@ proc acceptIRC {s x y} {
 }
 #
 proc dbgSIN {sock} {
-    if [eof $sock] {
+    if {[eof $sock]} {
 	close $sock
 	.@dbgsrv.txt.txt insert end {**** Connection closed} in "\n"
     } {
