@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/initial.tcl,v $
-# $Date: 1998/03/11 10:52:05 $
-# $Revision: 1.18.1.161 $
+# $Date: 1998/04/29 11:44:33 $
+# $Revision: 1.18.1.165 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -159,9 +159,8 @@ proc helper {ptn cmd args} {
 #
 proc srcit {file what} {
     if {[file exists $file]} {
-	if {[catch {uplevel #0 source \{$file\}} msg]} {
-	    puts stderr "**** Error in the $what file - $msg"
-	    bgerror Error
+	if {[catch {uplevel #0 source [list $file]} msg]} {
+	    tellError {} Error "**** Error in the $what file - $msg"
 	    exit 1
 	}
 	return 1
@@ -185,7 +184,7 @@ proc InitImages {} {
 	set DIms($x) [image create photo -file [file join $f $x.gif]]
     }
     global zDIOff zDIOn zDIOff1 zDIOn1 zKeyGif zSpkGif zNSpkGif zII \
-      zNOII zLock zUnlock
+      zNOII zLock zUnlock zLogo
     set zDIOff [image create photo -file [file join $f off.gif]]
     set zDIOn  [image create photo -file [file join $f on.gif]]
     set zDIOff1 [image create photo -file [file join $f off1.gif]]
@@ -197,6 +196,7 @@ proc InitImages {} {
     set zNOII [image create photo -file [file join $f noii.gif]]
     set zLock [image create photo -file [file join $f lock.gif]]
     set zUnlock [image create photo -file [file join $f unlock.gif]]
+    set zLogo [image create photo -file [file join $f zlogo.gif]]
     setupImages
 }
 #
@@ -343,7 +343,7 @@ Continue?}]} {
 	look		standard
 	action		Shift-Return
 	sepColor	red
-	ignore		{Notices Public Invites Wallops Notes CTCP Others}
+	ignore		{Msgs Notices Public Invites Wallops Notes CTCP Others}
 	scriptpath	[list [file join $zircon(lib) scripts]]
 	pluginpath	[list [file join $zircon(lib) plugins]]
 	serversStyle	pulldown
@@ -395,6 +395,16 @@ Continue?}]} {
     set zWClose [after $zWInc closeWindows]
     InitGlobals
     if {$DEBUG} zDBGControl
+    set ops 1
+    foreach x {Font Foreground Background} {
+        switch {} [option get . operator$x {}] {} default {
+	    set ops 0
+	    break
+	}
+    }
+    if {$ops} {
+        foreach x [Net :: list] { $x configure -ircIIops 1 }
+    }
     destroy .ad
     checkHeight [MainControl]
     bind [MainControl] <Configure> {checkHeight [winfo toplevel %W]}
