@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/main.tcl,v $
-# $Date: 1998/03/17 09:36:02 $
-# $Revision: 1.18.1.79 $
+# $Date: 1998/04/15 12:56:14 $
+# $Revision: 1.18.1.81 $
 #
 package provide zircon 1.18
 #
@@ -341,7 +341,7 @@ proc irc324 {net prefix param pargs} {
     switch nil [set chn [Channel :: find $chan $net]] {
 	$net inform "Mode for $chan : $mode"
     } default {
-	$chn mode $mode
+	$chn mode $mode $prefix
     }
 }
 #
@@ -376,7 +376,7 @@ proc afterMOTD {net prefix param pargs} {
     if {!$zircon(j)} {
 	foreach id [$net channels] {
 	    switch $id [getDefault defChan $net] {} default {
-		if {[$id join] || [$id active]} {
+		if {[$id join] || [$id active] } {
 		    $id slowJoin
 		} \
 		elseif {[$id monitor]} { $net monitor $id }
@@ -384,6 +384,7 @@ proc afterMOTD {net prefix param pargs} {
 	}
 	foreach id [$net messages] {
 	    switch $id $defMsg($net) {} default {
+	    	if {[$id noshow]} continue
 		switch nil [User :: find [$id name] $net] {} default {
 		    $id show
 		    $id flag normal
