@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/misc.tcl,v $
-# $Date: 1998/03/02 11:57:48 $
-# $Revision: 1.18.1.41 $
+# $Date: 1998/04/20 11:42:23 $
+# $Revision: 1.18.1.42 $
 #
 package provide zircon 1.18
 #
@@ -498,7 +498,7 @@ proc findURL {win x y net} {
 }
 #
 proc doHelp {net topic args} {
-    switch {} [set s [lindex $args 0]] {} default {$net msg $s $topic}
+    switch {} [set s [lindex $args 0]] {} default {$net qSend PRIVMSG $s :$topic}
 }
 #
 proc getHelp {net} {
