@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/misc2.tcl,v $
-# $Date: 1998/04/14 15:22:10 $
-# $Revision: 1.18.1.29 $
+# $Date: 1998/04/28 13:15:34 $
+# $Revision: 1.18.1.33 $
 #
 #
 package provide zircon 1.18
@@ -43,7 +43,10 @@ proc /ADMIN {net chid arg} { $net nsend ADMIN [lindex $arg 0]}
 #
 proc /ALIAS {net chid arg} { sillyPerson $net }
 #
-proc /ASSIGN {net chid arg} { sillyPerson $net }
+proc /ASSIGN {net chid arg} {
+    upvar #0 uVars$net uvars
+    set uvars([lindex $arg 0]) [lindex $arg 1]
+}
 #
 proc /AWAY {net chid arg} { $net AWAY $arg }
 #
@@ -63,7 +66,7 @@ proc /CD {net chid arg} {
 #
 proc /CHANNEL {net chid arg} { channelJoin $net [lindex $arg 0] }
 #
-proc /CLEAR {net chid arg} { sillyPerson $net }
+proc /CLEAR {net chid arg} { $chid clear 1 }
 #
 proc /COMMENT {net chid arg} { }
 #
@@ -124,11 +127,6 @@ proc /DCC {net chid arg} {
 	}
     CLOSE -
     LIST {buildDCCList $net}
-    close {
-	    set typ [lindex $arg 1]
-	    set gusr [User :: make $net [lindex $arg 2]]
-	    sillyPerson $net
-	}
     default { sillyPerson $net }
     }
 }
@@ -192,7 +190,42 @@ proc /HOOK {net chid arg} { sillyPerson $net }
 #
 proc /IF {net chid arg} { sillyPerson $net }
 #
-proc /IGNORE {net chid arg} { sillyPerson $net }
+proc flgAdd {lst flag op} {
+    switch -- $flag {
+    {}	{ listincl lst $op}
+    -	{ listkill lst $op }
+    +	{ }
+    ^	{ }
+    }
+    return $lst
+}
+#
+proc /IGNORE {net chid arg} {
+    global zircon
+    if {[string match *@* [set nk [lindex $arg 0]]]} {
+    	set nk *!$nk
+    } {
+    	append nk !*@*
+    }
+    set ign {}
+    foreach x [lrange $arg 1 end] {
+        regexp {^([-+^]?)(.*)} $x m flag op
+        switch [string tolower $op] {
+	msgs            -
+	notices         -
+	public          -
+	invites         -
+	wallops         -
+	notes           -
+	ctcp            -
+	crap            { set ign [flgAdd $ign $flag $op] }
+	all             { set ign [string tolower $zircon(ignore)] }
+	none            { ignoreRemove $net $nk ; return}
+	}
+    }
+    $net eval "ignore [list $nk] $ign"
+    $net configure +confChange Ignores
+}
 #
 proc /INFO {net chid arg} { $net INFO $arg }
 #
@@ -220,7 +253,28 @@ proc /LEAVE {net chid arg} { /PART $net $chid $arg }
 #
 proc /LINKS {net chid arg} { $net LINKS [lindex $arg 0] [lindex $arg 1] }
 #
-proc /LIST {net chid arg} { sillyPerson $net }
+proc /LIST {net chid arg} { 
+    set chan {}
+    while {$arg != {}} {
+	set inc 1
+        switch -glob -- [string toupper [lindex $arg 0]] {
+	-MIN	{ $net configure -minMembers [lindex $arg 1] ; set inc 2}
+	-MAX	{ $net configure -maxMembers [lindex $arg 1] ; set inc 2}
+	-PUBLIC { $net configure -showPublic 1 -showPrivate 0 -showLocal 0}
+	-PRIVATE { $net configure -showPrivate 1 -showPublic 0 -showlocal 0}
+	-ALL	{ $net configure -showPublic 1 -showPrivate 1 -showLocal 1}
+	-TOPIC	{ $net configure -topicOnly 1}
+	-WIDE	{ }
+	-NAME	{ $net configure -sorted 1 -sortNames 1}
+	-USERS	{ $net configure -sorted 1 -sortNames 0}
+	-*	{ tellError $net /LIST {Invalid option} ; return }
+	\*	{ set chan [$chid name] ; break }
+	default { set chan [lindex $arg 0] ; break }
+	}
+	set arg [lrange $arg $inc end]
+    }
+    $net channelList $chan
+}
 #
 proc /LOAD {net chid arg} {  sillyPerson $net }
 #
@@ -337,7 +391,7 @@ proc /REHASH {net chid arg} { $net q1Send REHASH }
 #
 proc /RESTART {net chid arg} { $net q1Send RESTART }
 #
-proc /SAVE {net chid arg} { sillyPerson $net }
+proc /SAVE {net chid arg} { saverc $net }
 #
 proc /SAY {net chid arg} { $chid send $arg }
 #
@@ -351,11 +405,24 @@ proc /SERVER {net chid arg} {
     $net changeServer $sv
 }
 #
-proc /SET {net chid arg} { sillyPerson $net }
+proc setBool {chan var val} {
+    upvar #0 $chan cdata
+    switch [string toupper $val] \
+    ON		{ set cdata($var) 1 }
+    OFF		{ set cdata($var) 1 }
+    TOGGLE	{ set cdata($var) [expr {!$cdata($var)}] }
+}
+#
+proc /SET {net chid arg} { 
+    switch [string toupper [lindex $arg 0]] \
+    BEEP { setBool $chid quiet [lindex $arg 1] } \
+    BEEP_MAX { $net configure -beeplimit [lindex $arg 1] } \
+    CHANNEL_NAME_WIDTH { $net configure -namewidth [lindex $arg 1] }
+}
 #
 proc /SIGNOFF {net chid arg} { $net doQuit $arg }
 #
-proc /SLEEP {net chid arg} { sillyPerson $net }
+proc /SLEEP {net chid arg} { after [lindex $arg 0] }
 #
 proc /SQUIT {net chid arg} {
     set foo [deCap $arg]
@@ -368,13 +435,15 @@ proc /SUMMON {net chid arg} { $net qSend SUMMON [colonLast $arg] }
 #
 proc /TIME {net chid arg} { $net qSend TIME [colonLast $arg] }
 #
-proc /TIMER {net chid arg} { sillyPerson $net }
+proc /TIMER {net chid arg} { }
 #
 proc /TOPIC {net chid arg} { $chid configure -topic $arg}
 #
 proc /TRACE {net chid arg} { $net nsend TRACE $arg }
 #
-proc /TYPE {net chid arg} { sillyPerson $net }
+proc /TYPE {net chid arg} { 
+    [$chid window].cmd.entry insert insert $arg
+}
 #
 proc /USERHOST {net chid arg} {
     foreach x $arg {
