@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/saverc.tcl,v $
-# $Date: 1998/02/10 10:48:47 $
-# $Revision: 1.18.1.24 $
+# $Date: 1998/04/14 15:22:11 $
+# $Revision: 1.18.1.25 $
 #
 package provide zircon 1.18
 #
@@ -29,7 +29,8 @@ proc putProc {desc cmnt name list dflt args} {
 proc saverc {net} {
     global zircon
     switch default [set nn [$net name]] {
-    	set rc [file join [set rcd [list $zircon(prefdir)]] preferences]
+    	set rc [file join $zircon(prefdir) preferences]
+	set rcd [list $zircon(prefdir)]
 	set dflt 1
     } default {
 	set rcd [file join $zircon(prefdir) netspaces]
