@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/servers.tcl,v $
-# $Date: 1997/06/07 13:14:42 $
-# $Revision: 1.18.1.16 $
+# $Date: 1998/02/10 10:48:48 $
+# $Revision: 1.18.1.18 $
 #
 package provide zircon 1.18
 #
@@ -33,8 +33,8 @@ proc serverCmd {net cmd} {
     set def "(Default host is $srv)"
     switch $cmd {
     Oper {
-	    if [$net ircop] {
-		if [askUser {} {IRC OP} {Really stop being an IRC Operator?}] {
+	    if {[$net ircop]} {
+		if {[askUser {} {IRC OP} {Really stop being an IRC Operator?}]} {
 		    $net deIRCOp
 		}
 	    } {
@@ -98,8 +98,8 @@ proc serverCmd {net cmd} {
 #
 proc doSquit {net srv} {
     switch {} $srv return
-    tkwait window [mkDialog SQUIT {} Squit "Really Squit server \"$srv\"?" \
-      {} [list ok "$net qSend SQUIT :$srv"] [list cancel {}]]
+    tkwait window [mkEntryBox {} SQUIT "Really Squit server \"$srv\"?" \
+      [list [list message {}]] [list ok "$net SQUIT $srv"] [list cancel {}]]
 }
 #
 proc kill {net who} {
@@ -168,7 +168,7 @@ proc tracewin {op net prefix param pargs args} {
     s	{ set var swin ; set type Stats ; set cmd "askStats $net {} $tsite"}
     }
     upvar #0 $var wstat
-    if ![info exists wstat($net)] {
+    if {![info exists wstat($net)]} {
 	set w [toplevel .@[newName trace] -class Zircon]
 	wm resizable $w 1 1
 	wm protocol $w WM_DELETE_WINDOW "destroy $w ; catch {unset ${var}($net)}"
@@ -208,7 +208,7 @@ proc irc364 {net prefix param pargs} {
 #
 proc irc365 {net prefix param pargs} {
     global linksInfo
-    if ![info exists linksInfo($net)] { set linksInfo($net) {No Links} }
+    if {![info exists linksInfo($net)]} { set linksInfo($net) {No Links} }
     mkInfoBox $net LINKS {} "[string range $prefix 1 end] Links [getDate]" $linksInfo($net)
     unset linksInfo($net)
 }
