@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/tcl75.tcl,v $
-# $Date: 1997/04/28 10:31:06 $
-# $Revision: 1.18.1.17 $
+# $Date: 1998/02/09 16:57:13 $
+# $Revision: 1.18.1.18 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -12,7 +12,7 @@
 package provide interp 7.5
 #
 #
-proc sconf {sk} {
+proc sconf {sk enc} {
     global hostIPaddress
     fconfigure $sk -buffering line -translation auto -blocking 0
     if ![info exists hostIPaddress] {
