@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/tcl76.tcl,v $
-# $Date: 1996/12/06 10:39:05 $
-# $Revision: 1.18.1.15 $
+# $Date: 1998/02/09 16:57:14 $
+# $Revision: 1.18.1.16 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -12,7 +12,7 @@
 #
 package provide interp 7.6
 #
-proc sconf {sk} {
+proc sconf {sk enc} {
     global hostIPaddress
     fconfigure $sk -buffering line -translation {auto lf} -blocking 0
     if ![info exists hostIPaddress] {
