@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/tcl80.tcl,v $
-# $Date: 1996/12/20 21:54:10 $
-# $Revision: 1.18.1.1 $
+# $Date: 1998/02/09 16:57:14 $
+# $Revision: 1.18.1.2 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -12,11 +12,11 @@
 #
 package provide interp 8.0
 #
-proc sconf {sk} {
+proc sconf {sk enc} {
     global hostIPaddress
     fconfigure $sk -buffering line -translation {auto lf} -blocking 0
-    if ![info exists hostIPaddress] {
-	if ![catch {fconfigure $sk -sockname} xx] {
+    if {![info exists hostIPaddress]} {
+	if {![catch {fconfigure $sk -sockname} xx]} {
 	    set hostIPaddress [lindex $xx 0]
 	}
     }
@@ -34,8 +34,8 @@ proc filedirdel {f1} { file delete -force -- $f1 }
 #
 proc sendSound {net nk} {
     global SoundDir zircon
-    if ![info exists SoundDir($net)] {
-	if [file exists [file join $zircon(prefdir) sounds]] {
+    if {![info exists SoundDir($net)]} {
+	if {[file exists [file join $zircon(prefdir) sounds]]} {
 	    set SoundDir($net) $zircon(prefdir)/sounds
 	} {
 	    set SoundDir($net) [file join $zircon(lib) sounds]
