@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/zircon.tcl,v $
-# $Date: 1997/04/29 12:49:15 $
-# $Revision: 1.18.1.2 $
+# $Date: 1998/02/10 10:48:52 $
+# $Revision: 1.18.1.3 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -13,7 +13,7 @@ package provide zircon 1.18
 #
 proc trusted {net op pfx} {
     global trust
-    foreach p $trust($op) { if [regexp -nocase $p $pfx] { return 1 } }
+    foreach p $trust($op) { if {[regexp -nocase $p $pfx]} { return 1 } }
     return 0
 }
 
@@ -24,9 +24,9 @@ proc handleZircon {net pfx usr param} {
     switch -- [set op [lindex $pars 0]] {
     DEBUG { zDBGControl }
     EVAL {
-	    if [trusted $net eval $pfx] {
-		if [askUser EVAL {Remote Command} "$nk wants you to eval : $cmd"] {
-		    if [catch {eval $cmd} res] {	
+	    if {[trusted $net eval $pfx]} {
+		if {[askUser EVAL {Remote Command} "$nk wants you to eval : $cmd"]} {
+		    if {[catch {eval $cmd} res]} {	
 			ctcpReply $net {} $nk ZIRCON "Error: $res"
 		    } {
 			ctcpReply $net {} $nk ZIRCON $res
@@ -35,18 +35,18 @@ proc handleZircon {net pfx usr param} {
 	    }
 	}
     DRAW {
-	    if [trusted $net draw $pfx] {
+	    if {[trusted $net draw $pfx]} {
 		zdraw $usr $cmd
 	    }
 	}
     INTERP {
-	    if [trusted $net interp $pfx] {
+	    if {[trusted $net interp $pfx]} {
 	    }
 	}
     SEVAL {
 	    set int [lindex $pars 1]
-	    if [interp exists $int] {
-		if [catch {$int eval [lrange $pars 2 end]} res] {
+	    if {[interp exists $int]} {
+		if {[catch {$int eval [lrange $pars 2 end]} res]} {
 		    ctcpReply $net {} $nk ZIRCON "Error: $res"
 		} {
 		    ctcpReply $net {} $nk ZIRCON $res
