@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/send.tcl,v $
-# $Date: 1998/03/25 13:46:36 $
-# $Revision: 1.18.1.26 $
+# $Date: 1998/04/27 11:46:15 $
+# $Revision: 1.18.1.28 $
 #
 package provide Dcc 1.18
 #
@@ -67,11 +67,10 @@ proc endDCC {type who conn net msg args} {
     set file [lindex [lindex $gsnet($who) $x] 1]
     listdel gsnet($who) $x
     switch {} $gsnet($who) {unset gsnet($who)}
-    if {[winfo exists .@dls$net]} { buildDCCList $net }
     if {![winfo exists .@$conn]} {
 	$net inform $msg
     } {
-	catch {destroy .@$conn.slide .@$conn.txt .@$conn.txt2}
+	catch {destroy .@$conn.slide .@$conn.txt}
 	if {[winfo exists .@$conn.done]} {
 	    .@$conn.done configure -text $msg
 	} {
@@ -79,7 +78,9 @@ proc endDCC {type who conn net msg args} {
 	}
 	.@$conn.cancel configure -text [trans dismiss] -command "destroy .@$conn"
     }
-    close $conn
+    if {[catch {close $conn} msg]} {
+        $net inform "Error closing DCC connection : $msg"
+    }
     catch {uplevel #0 unset tl($conn)}
     switch $type Get {
         switch {} $args {} default {
@@ -190,40 +191,4 @@ proc handleAccept {net usr fln port posn} {
 	}
     }
 }
-#
-proc dccWindow {conn usr array file} {
-    if {[winfo exists [set w .@$conn]]} return
-    toplevel $w -class Zircon
-    switch $array Send {
-	wm title $w "DCC send $file to [$usr name]"
-    } default {
-	wm title $w "DCC get $file from [$usr name]"
-    }
-    wm protocol $w WM_DELETE_WINDOW {}
-    scale $w.slide -from 0 -to 100 -tickinterval 20 \
-       -state disabled -length 200 -orient horizontal
-    grid columnconfigure $w 0 -weight 1
-    grid $w.slide -padx 10 -pady 5 -sticky ew
-    frame $w.txt
-    grid columnconfigure $w.txt 0 -weight 1
-    grid columnconfigure $w.txt 1 -weight 1
-    grid [label $w.txt.bytes -text {0 bytes transferred}] \
-      [label $w.txt.pcnt -text {0% complete}] -padx 10 -sticky ew
-    frame $w.txt2
-#    pack [label $w.txt2.left -text {}]
-    grid $w.txt -sticky ew -pady 5
-    button $w.cancel -text [trans cancel] \
-      -command "killDel $array[$usr net] $usr {$file} ; destroy .@$conn"
-    grid $w.cancel -sticky ew
-}
-#
-proc dccProgress {conn bytes pcnt min sec} {
-    set w .@$conn
-    $w.txt.bytes configure -text "$bytes bytes transferred."
-    $w.txt.pcnt configure -text "$pcnt% complete"
-#    $w.txt2.left configure -text "${min}m ${sec}s remaining"
-    $w.slide configure -state normal
-    $w.slide set $pcnt
-    $w.slide configure -state disabled
-    update idletasks
-}
+
